@@ -20,8 +20,16 @@ pub(crate) async fn setup<S: AsRef<str> + Copy>(
     .collect();
   let mut memory_loader = MemoryLoader::new(sources, vec![]);
   let root = ModuleSpecifier::parse(root.as_ref()).unwrap();
-  let graph =
-    create_graph(root.clone(), &mut memory_loader, None, None, None).await;
+  let graph = create_graph(
+    vec![root.clone()],
+    false,
+    None,
+    &mut memory_loader,
+    None,
+    None,
+    None,
+  )
+  .await;
   (graph, root)
 }
 
@@ -120,8 +128,16 @@ async fn content_type_handling() {
   )];
   let mut memory_loader = MemoryLoader::new(sources, vec![]);
   let root = ModuleSpecifier::parse("https://example.com/a").unwrap();
-  let graph =
-    create_graph(root.clone(), &mut memory_loader, None, None, None).await;
+  let graph = create_graph(
+    vec![root.clone()],
+    false,
+    None,
+    &mut memory_loader,
+    None,
+    None,
+    None,
+  )
+  .await;
   let source_parser = deno_graph::DefaultSourceParser::new();
   let entries = DocParser::new(graph, false, &source_parser)
     .parse_with_reexports(&root)
@@ -157,8 +173,16 @@ async fn types_header_handling() {
   ];
   let mut memory_loader = MemoryLoader::new(sources, vec![]);
   let root = ModuleSpecifier::parse("https://example.com/a.js").unwrap();
-  let graph =
-    create_graph(root.clone(), &mut memory_loader, None, None, None).await;
+  let graph = create_graph(
+    vec![root.clone()],
+    false,
+    None,
+    &mut memory_loader,
+    None,
+    None,
+    None,
+  )
+  .await;
   let source_parser = deno_graph::DefaultSourceParser::new();
   let entries = DocParser::new(graph, false, &source_parser)
     .parse_with_reexports(&root)
